/*
    GNU LESSER GENERAL PUBLIC LICENSE
    Copyright (C) 2006 The Lobo Project

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    Contact info: lobochief@users.sourceforge.net
*/
package org.lobobrowser.html.renderer;

class PositionedRenderable {
	public static final PositionedRenderable[] EMPTY_ARRAY = new PositionedRenderable[0];
	public final BoundableRenderable renderable;
	public final boolean verticalAlignable;
	public final int ordinal;
	public final boolean isFloat;
	
	public PositionedRenderable(final BoundableRenderable renderable, final boolean verticalAlignable, int ordinal, boolean isFloat) {
		super();
		this.renderable = renderable;
		this.verticalAlignable = verticalAlignable;
		this.ordinal = ordinal;
		this.isFloat = isFloat;
	}		
}